@@ -51,7 +51,7 @@ from ..dbguielement import DbGUIElement
 from ..widgets.grampletbar import GrampletBar
 from ..configure import ConfigureDialog
 from gramps.gen.config import config
-from ..actiongroup import ActionGroup
+from ..uimanager import ActionGroup
 
 #------------------------------------------------------------------------------
 #
@@ -97,25 +97,24 @@ class PageView(DbGUIElement, metaclass=ABCMeta):
         self.uistate = uistate
         self.action_list = []
         self.action_toggle_list = []
-        self.action_toolmenu_list = []
-        self.action_toolmenu = {} #easy access to toolmenuaction and proxies
         self.action_group = None
         self.additional_action_groups = []
         self.additional_uis = []
-        self.ui_def = '''<ui>
-          <menubar name="MenuBar">
-            <menu action="ViewMenu">
-              <placeholder name="Bars">
-                <menuitem action="Sidebar"/>
-                <menuitem action="Bottombar"/>
-              </placeholder>
-            </menu>
-          </menubar>
-        </ui>'''
+        self.ui_def = ['''
+          <placeholder id="Bars">
+            <item>
+              <attribute name="action">win.Sidebar</attribute>
+              <attribute name="label" translatable="yes">_Sidebar</attribute>
+            </item>
+             <item>
+              <attribute name="action">win.Bottombar</attribute>
+              <attribute name="label" translatable="yes">_Bottombar</attribute>
+            </item>
+          </placeholder>
+            ''']
         self.dirty = True
         self.active = False
         self._dirty_on_change_inactive = True
-        self.func_list = {}
 
         if isinstance(self.pdata.category, tuple):
             self.category, self.translated_category = self.pdata.category
@@ -138,6 +137,8 @@ class PageView(DbGUIElement, metaclass=ABCMeta):
         self.top = None
         self.sidebar = None
         self.bottombar = None
+        self.widget = None
+        self.vpane = None
 
         DbGUIElement.__init__(self, dbstate.db)
 
@@ -154,17 +155,20 @@ class PageView(DbGUIElement, metaclass=ABCMeta):
                                      self.ident + "_bottombar",
                                      defaults[1])
         hpane = Gtk.Paned()
-        vpane = Gtk.Paned(orientation=Gtk.Orientation.VERTICAL)
-        hpane.pack1(vpane, resize=True, shrink=False)
+        self.vpane = Gtk.Paned(orientation=Gtk.Orientation.VERTICAL)
+        hpane.pack1(self.vpane, resize=True, shrink=False)
         hpane.pack2(self.sidebar, resize=False, shrink=False)
         hpane.show()
-        vpane.show()
+        self.vpane.show()
 
-        widget = self.build_widget()
-        widget.show_all()
-        vpane.pack1(widget, resize=True, shrink=False)
-        vpane.pack2(self.bottombar, resize=False, shrink=True)
-        self._setup_slider_config(vpane, 'vpane.slider-position')
+        self.widget = self.build_widget()
+        self.widget.show_all()
+        self.widget.set_name('view')
+        self.vpane.pack1(self.widget, resize=True, shrink=False)
+        self.vpane.pack2(self.bottombar, resize=False, shrink=True)
+        self.vpane.show()
+        self._config.register('vpane.slider-position', -1)
+        self.vpane.set_position(self._config.get('vpane.slider-position'))
 
         self.sidebar_toggled(self.sidebar.get_property('visible'))
         self.hpane_sig = hpane.connect("draw", self.set_page_slider)
@@ -201,24 +205,24 @@ class PageView(DbGUIElement, metaclass=ABCMeta):
         """
         self._config.set(setting, widget.get_position())
 
-    def __sidebar_toggled(self, action):
+    def __sidebar_toggled(self, action, value):
         """
         Called when the sidebar is toggled.
         """
-        active = action.get_active()
-        if active:
+        action.set_state(value)  # change GUI
+        if value.get_boolean():
             self.sidebar.show()
             self.sidebar_toggled(True)
         else:
             self.sidebar.hide()
             self.sidebar_toggled(False)
 
-    def __bottombar_toggled(self, action):
+    def __bottombar_toggled(self, action, value):
         """
         Called when the bottombar is toggled.
         """
-        active = action.get_active()
-        if active:
+        action.set_state(value)  # change GUI
+        if value.get_boolean():
             self.bottombar.show()
         else:
             self.bottombar.hide()
@@ -277,7 +281,7 @@ class PageView(DbGUIElement, metaclass=ABCMeta):
                     def get_data(self):
                         return self.data
                 class Context:
-                    targets = [drag_type.name()]
+                    targets = [Gdk.atom_intern(drag_type.name(), False)]
                     action = 1
                     def list_targets(self):
                         return Context.targets
@@ -312,12 +316,6 @@ class PageView(DbGUIElement, metaclass=ABCMeta):
             return True
         return False
 
-    def call_function(self, key):
-        """
-        Calls the function associated with the key value
-        """
-        self.func_list.get(key)()
-
     def post(self):
         """
         Called after a page is created.
@@ -332,6 +330,9 @@ class PageView(DbGUIElement, metaclass=ABCMeta):
         self.sidebar.set_active()
         self.bottombar.set_active()
         self.active = True
+        new_title = "%s - %s - Gramps" % (self.dbstate.db.get_dbname(),
+                                      self.get_title())
+        self.uistate.window.set_title(new_title)
         if self.dirty:
             self.uistate.set_busy_cursor(True)
             self.build_tree()
@@ -345,6 +346,11 @@ class PageView(DbGUIElement, metaclass=ABCMeta):
         self.bottombar.set_inactive()
         self.active = False
 
+    def post_create(self):
+        if self.vpane:
+            self._setup_slider_config(self.vpane, 'vpane.slider-position')
+            self.vpane = None
+
     @abstractmethod
     def build_tree(self):
         """
@@ -370,14 +376,15 @@ class PageView(DbGUIElement, metaclass=ABCMeta):
         Turns off the visibility of the View's action group, if defined
         """
         if self.action_group:
-            self.action_group.set_visible(False)
+            self.uistate.uimanager.set_actions_visible(self.action_group,
+                                                       False)
 
     def enable_action_group(self, obj):
         """
         Turns on the visibility of the View's action group, if defined
         """
         if self.action_group:
-            self.action_group.set_visible(True)
+            self.uistate.uimanager.set_actions_visible(self.action_group, True)
 
     def get_stock(self):
         """
@@ -435,12 +442,10 @@ class PageView(DbGUIElement, metaclass=ABCMeta):
         View. The user typically defines self.action_list and
         self.action_toggle_list in this function.
         """
-        self._add_toggle_action('Sidebar', None, _('_Sidebar'),
-             "<shift><PRIMARY>R", None, self.__sidebar_toggled,
-             self.sidebar.get_property('visible'))
-        self._add_toggle_action('Bottombar', None, _('_Bottombar'),
-             "<shift><PRIMARY>B", None, self.__bottombar_toggled,
-             self.bottombar.get_property('visible'))
+        self._add_toggle_action('Sidebar', self.__sidebar_toggled,
+            '<shift><PRIMARY>R', self.sidebar.get_property('visible'))
+        self._add_toggle_action('Bottombar', self.__bottombar_toggled,
+            '<shift><PRIMARY>B', self.bottombar.get_property('visible'))
 
     def __build_action_group(self):
         """
@@ -452,31 +457,19 @@ class PageView(DbGUIElement, metaclass=ABCMeta):
         if len(self.action_list) > 0:
             self.action_group.add_actions(self.action_list)
         if len(self.action_toggle_list) > 0:
-            self.action_group.add_toggle_actions(self.action_toggle_list)
+            self.action_group.add_actions(self.action_toggle_list)
 
-    def _add_action(self, name, icon_name, label, accel=None, tip=None,
-                   callback=None):
+    def _add_action(self, name, callback=None, accel=None):
         """
         Add an action to the action list for the current view.
         """
-        self.action_list.append((name, icon_name, label, accel, tip,
-                                 callback))
+        self.action_list.append((name, callback, accel))
 
-    def _add_toggle_action(self, name, icon_name, label, accel=None,
-                           tip=None, callback=None, value=False):
+    def _add_toggle_action(self, name, callback=None, accel= None, value=False):
         """
         Add a toggle action to the action list for the current view.
         """
-        self.action_toggle_list.append((name, icon_name, label, accel,
-                                        tip, callback, value))
-
-    def _add_toolmenu_action(self, name, label, tooltip, callback,
-                             arrowtooltip):
-        """
-        Add a menu action to the action list for the current view.
-        """
-        self.action_toolmenu_list.append((name, label, tooltip, callback,
-                                          arrowtooltip))
+        self.action_toggle_list.append((name, callback, accel, value))
 
     def get_actions(self):
         """
