@@ -435,6 +435,9 @@ class Verify(tool.Tool, ManagedWindow, UpdateCallback):
                 Disconnected(self.db, person),
                 InvalidBirthDate(self.db, person, invdate),
                 InvalidDeathDate(self.db, person, invdate),
+                BirthEqualsDeath(self.db, person),
+                BirthEqualsMarriage(self.db, person),
+                DeathEqualsMarriage(self.db, person),
                 ]
 
             for rule in rule_list:
@@ -539,7 +542,10 @@ class VerifyResults(ManagedWindow):
                                         GObject.TYPE_BOOLEAN)
         self.filt_model = self.real_model.filter_new()
         self.filt_model.set_visible_column(VerifyResults.TRUE_COL)
-        self.sort_model = self.filt_model.sort_new_with_model()
+        if hasattr(self.filt_model, "sort_new_with_model"):
+            self.sort_model = self.filt_model.sort_new_with_model()
+        else:
+            self.sort_model = Gtk.TreeModelSort.new_with_model(self.filt_model)
         self.warn_tree.set_model(self.sort_model)
 
         self.renderer = Gtk.CellRendererText()
@@ -656,18 +662,19 @@ class VerifyResults(ManagedWindow):
         self.closeall()
 
     def hide_toggled(self, button):
+        self.filt_model = self.real_model.filter_new()
         if button.get_active():
             button.set_label(_("_Show all"))
-            self.filt_model = self.real_model.filter_new()
             self.filt_model.set_visible_column(VerifyResults.SHOW_COL)
-            self.sort_model = self.filt_model.sort_new_with_model()
-            self.warn_tree.set_model(self.sort_model)
         else:
-            self.filt_model = self.real_model.filter_new()
-            self.filt_model.set_visible_column(VerifyResults.TRUE_COL)
-            self.sort_model = self.filt_model.sort_new_with_model()
-            self.warn_tree.set_model(self.sort_model)
             button.set_label(_("_Hide marked"))
+            self.filt_model.set_visible_column(VerifyResults.TRUE_COL)
+        if hasattr(self.filt_model, "sort_new_with_model"):
+            self.sort_model = self.filt_model.sort_new_with_model()
+        else:
+            self.sort_model = Gtk.TreeModelSort.new_with_model(
+                self.filt_model)
+        self.warn_tree.set_model(self.sort_model)
 
     def selection_toggled(self, cell, path_string):
         sort_path = tuple(map(int, path_string.split(':')))
@@ -705,7 +712,8 @@ class VerifyResults(ManagedWindow):
 
     def double_click(self, obj, event):
         """ the user wants to edit the selected person or family """
-        if event.type == Gdk.EventType._2BUTTON_PRESS and event.button == 1:
+        if (event.type == Gdk.EventType.DOUBLE_BUTTON_PRESS
+                and event.button == 1):
             (model, node) = self.selection.get_selected()
             if not node:
                 return
@@ -1781,3 +1789,55 @@ class OldAgeButNoDeath(PersonRule):
         """ return the rule's error message """
         return _("Old age but no death")
 
+class BirthEqualsDeath(PersonRule):
+    """ test if a person's birth date is the same as their death date """
+    ID = 33
+    SEVERITY = Rule.WARNING
+    def broken(self):
+        """ return boolean indicating whether this rule is violated """
+        birth_date = get_birth_date(self.db, self.obj)
+        death_date = get_death_date(self.db, self.obj)
+        birth_ok = birth_date > 0 if birth_date is not None else False
+        death_ok = death_date > 0 if death_date is not None else False
+        return death_ok and birth_ok and birth_date == death_date
+
+    def get_message(self):
+        """ return the rule's error message """
+        return _("Birth equals death")
+
+class BirthEqualsMarriage(PersonRule):
+    """ test if a person's birth date is the same as their marriage date """
+    ID = 34
+    SEVERITY = Rule.ERROR
+    def broken(self):
+        """ return boolean indicating whether this rule is violated """
+        birth_date = get_birth_date(self.db, self.obj)
+        birth_ok = birth_date > 0 if birth_date is not None else False
+        for fhandle in self.obj.get_family_handle_list():
+            family = self.db.get_family_from_handle(fhandle)
+            marr_date = get_marriage_date(self.db, family)
+            marr_ok = marr_date > 0 if marr_date is not None else False
+            return marr_ok and birth_ok and birth_date == marr_date
+
+    def get_message(self):
+        """ return the rule's error message """
+        return _("Birth equals marriage")
+
+class DeathEqualsMarriage(PersonRule):
+    """ test if a person's death date is the same as their marriage date """
+    ID = 35
+    SEVERITY = Rule.WARNING # it's possible
+    def broken(self):
+        """ return boolean indicating whether this rule is violated """
+        death_date = get_death_date(self.db, self.obj)
+        death_ok = death_date > 0 if death_date is not None else False
+        for fhandle in self.obj.get_family_handle_list():
+            family = self.db.get_family_from_handle(fhandle)
+            marr_date = get_marriage_date(self.db, family)
+            marr_ok = marr_date > 0 if marr_date is not None else False
+            return marr_ok and death_ok and death_date == marr_date
+
+    def get_message(self):
+        """ return the rule's error message """
+        return _("Death equals marriage")
+
