@@ -64,42 +64,107 @@ from gramps.plugins.lib.maps.geography import GeoGraphyView
 #
 #-------------------------------------------------------------------------
 
-_UI_DEF = '''\
-<ui>
-<menubar name="MenuBar">
-<menu action="GoMenu">
-  <placeholder name="CommonGo">
-    <menuitem action="Back"/>
-    <menuitem action="Forward"/>
-    <separator/>
-    <menuitem action="HomePerson"/>
-    <separator/>
-  </placeholder>
-</menu>
-<menu action="EditMenu">
-  <placeholder name="CommonEdit">
-    <menuitem action="PrintView"/>
-  </placeholder>
-</menu>
-<menu action="BookMenu">
-  <placeholder name="AddEditBook">
-    <menuitem action="AddBook"/>
-    <menuitem action="EditBook"/>
-  </placeholder>
-</menu>
-</menubar>
-<toolbar name="ToolBar">
-<placeholder name="CommonNavigation">
-  <toolitem action="Back"/>
-  <toolitem action="Forward"/>
-  <toolitem action="HomePerson"/>
-</placeholder>
-<placeholder name="CommonEdit">
-  <toolitem action="PrintView"/>
-</placeholder>
-</toolbar>
-</ui>
-'''
+_UI_DEF = [
+    '''
+      <placeholder id="CommonGo">
+      <section>
+        <item>
+          <attribute name="action">win.Back</attribute>
+          <attribute name="label" translatable="yes">_Back</attribute>
+        </item>
+        <item>
+          <attribute name="action">win.Forward</attribute>
+          <attribute name="label" translatable="yes">_Forward</attribute>
+        </item>
+      </section>
+      <section>
+        <item>
+          <attribute name="action">win.HomePerson</attribute>
+          <attribute name="label" translatable="yes">_Home</attribute>
+        </item>
+      </section>
+      </placeholder>
+''',
+    '''
+      <section id='CommonEdit' groups='RW'>
+        <item>
+          <attribute name="action">win.PrintView</attribute>
+          <attribute name="label" translatable="yes">Print...</attribute>
+        </item>
+      </section>
+''',
+    '''
+      <section id="AddEditBook">
+        <item>
+          <attribute name="action">win.AddBook</attribute>
+          <attribute name="label" translatable="yes">_Add Bookmark</attribute>
+        </item>
+        <item>
+          <attribute name="action">win.EditBook</attribute>
+          <attribute name="label" translatable="no">%s...</attribute>
+        </item>
+      </section>
+''' % _('Organize Bookmarks'),  # Following are the Toolbar items
+    '''
+    <placeholder id='CommonNavigation'>
+    <child groups='RO'>
+      <object class="GtkToolButton">
+        <property name="icon-name">go-previous</property>
+        <property name="action-name">win.Back</property>
+        <property name="tooltip_text" translatable="yes">'''
+    '''Go to the previous object in the history</property>
+        <property name="label" translatable="yes">_Back</property>
+        <property name="use-underline">True</property>
+      </object>
+      <packing>
+        <property name="homogeneous">False</property>
+      </packing>
+    </child>
+    <child groups='RO'>
+      <object class="GtkToolButton">
+        <property name="icon-name">go-next</property>
+        <property name="action-name">win.Forward</property>
+        <property name="tooltip_text" translatable="yes">'''
+    '''Go to the next object in the history</property>
+        <property name="label" translatable="yes">_Forward</property>
+        <property name="use-underline">True</property>
+      </object>
+      <packing>
+        <property name="homogeneous">False</property>
+      </packing>
+    </child>
+    <child groups='RO'>
+      <object class="GtkToolButton">
+        <property name="icon-name">go-home</property>
+        <property name="action-name">win.HomePerson</property>
+        <property name="tooltip_text" translatable="yes">'''
+    '''Go to the home person</property>
+        <property name="label" translatable="yes">_Home</property>
+        <property name="use-underline">True</property>
+      </object>
+      <packing>
+        <property name="homogeneous">False</property>
+      </packing>
+    </child>
+    </placeholder>
+''',
+    '''
+    <placeholder id='BarCommonEdit'>
+    <child groups='RO'>
+      <object class="GtkToolButton">
+        <property name="icon-name">document-print</property>
+        <property name="action-name">win.PrintView</property>
+        <property name="tooltip_text" translatable="yes">'''
+    '''Print or save the Map</property>
+        <property name="label" translatable="yes">Print...</property>
+        <property name="use-underline">True</property>
+      </object>
+      <packing>
+        <property name="homogeneous">False</property>
+      </packing>
+    </child>
+    </placeholder>
+    ''']
 
 # pylint: disable=no-member
 # pylint: disable=unused-variable
@@ -234,6 +299,7 @@ class GeoMoves(GeoGraphyView):
         self.lifeway_layer.clear_ways()
         self.date_layer.clear_dates()
         self.message_layer.clear_messages()
+        self.message_layer.set_font_attributes(None, None, None)
 
     def draw(self, menu, marks, color):
         """
